/* BBRegionShape.h				 
 *
 * This object is the backbone of each region shape. It maintains a list of 
 * shapes that have to be drawn to represent the region according the the
 * regions graphics settings.
 *
 * Usage: Don't use this class directly. 
 *		  It is a abstract class that should allow easy creation of new
 *		  region shapes.
 *	
 * Written by: 		Thomas Engel
 * Created:    		10.03.1994 (Copyleft)
 * Last modified: 	23.05.1994
 */

#import <3Dkit/3Dkit.h>

@interface BBRegionShape:N3DShape
{
	id		ourRegion;
	id		ourMolecule;
	id		subshapeList;
	id		style;
	NXColor	selectionColor;
}

- initFrom:aRegion asPartOf:aMolecule;
- regionClass;

- renderSelf:(N3DCamera *)theCamera;
- renderSelfAsBox:(N3DCamera *)theCamera;
- setRenderingStyle:aStyle;
- update;
- addSubshapesTo:aList;

- region;

// Depending on the type of sender-shape we will return the current 
// size and style values;

- (NXColor)selectionColor;
- (float)atomRadius:sender;
- (float)bondRadius:sender;

@end

/*
 * History: 23.05.94 Made it a kind of abstract class.
 *
 *			07.05.94 Changed the init method.
 *
 *			27.03.94 Add the renderStyle setting.
 *
 *			10.03.94 Extracted from the nomral BBRegion.
 *
 *
 * Bugs: - Nop
 */