/* BBFileFilterManager.h				 
 *
 * This FilterManager is resposible for the conversion of the different
 * molFileFormats (ways of storing molData) into useful objects.
 * The real work (read/write) is done by single filters that are known here.
 *
 * Notes: This object is invoked by every beaker when he wants to perform
 *		  some read/write. This frees the beaker from knowing were his objects
 *		  come from.
 *		  The best filter is chosen automatically.
 *
 * Written by: 		Thomas Engel
 * Created:    		15.11.1993 (Copyleft)
 * Last modified: 	01.11.1994
 */

#import <appkit/appkit.h>

// For future projects we should support fuzzy data. There might be
// situations where some filter will not be really sure about the data
// format. So they can return a fuzzy value. 0=NO, YES =1 and we add 
// MAYBE = 0.5

#define MAYBE		0.5

@interface BBFileFilterManager:Object
{
	id	filterList;
}

- init;
- free;

- readBeaker:aBeaker fromFile:(const char *)filename;

- addFilter:aFilter;
- removeFilter:aFilter;

@end

/*
 * History: 14.03.94 Made it a real manager. It now will handle different
 *					 filetypes.
 *
 *			14.01.94 Cleaned the parsing procedure.
 *
 *			13.01.94 Added the new parsing methods
 *
 *			28.12.93 Switch to a general initBeaker method.
 *
 *			15.11.93 Created this object to do a basic setup for a simple mol.
 *
 *
 * Bugs: - Because this object might someday be used by different beakers at
 *		   the same time I should add some locking or what ever. Right
 *		   this is no problem at all.
 */
