/* BBMasterInspector.m				 
 *
 * This is the BeakerBoys Master Inspector. Here all the other Inspectors
 * are created or have to register themselves.
 *
 * For interface-info see the header file. The comments in this file mostly
 * cover only the real implementation details.
 *
 * Written by: 		Thomas Engel
 * Created:    		20.11.1993 (Copyleft)
 * Last modified: 	12.05.1994
 */

#import "BBMasterInspector.h"

#import "BasicAtomInspector.subproj/BBBasicAtomInspector.h"
#import "RegionInspector.subproj/BBRegionInspector.h"
#import "MoleculeInspector.subproj/BBMoleculeInspector.h"
#import "AtomInspector.subproj/BBAtomInspector.h"
#import "BondInspector.subproj/BBBondInspector.h"
#import "BeakerInspector.subproj/BBBeakerInspector.h"
#import "CameraInspector.subproj/BBCameraInspector.h"

@implementation BBMasterInspector

- addDefaultInspectors
{
	// Let's add our inspectors after our super did.
	// Always remember. The order is important! Adding it later gives it
	// a higher priorty.
	
	[super addDefaultInspectors];
	
	[[BBBasicAtomInspector new] setManager:self];
	[[BBRegionInspector new] setManager:self];
	[[BBMoleculeInspector new] setManager:self];
	[[BBAtomInspector new] setManager:self];
	[[BBBondInspector new] setManager:self];
	[[BBBeakerInspector new] setManager:self];
	[[BBCameraInspector new] setManager:self];
	
	return self;
}


@end

/*
 * History: 12.05.94 Converted to fit BB... naming
 *
 *			08.02.94 Complete redesign to work with MiscInspectorManager. A
 *					 lot easyier now.
 *
 *			08.01.94 Changed to work with our new swapControllers.
 *
 *			20.12.93 Copied the code from the old InspectorManager and added
 *					 the default inspectors.
 *
 *
 * Bugs: Not here
 */